pub enum Rv32ZkndInstruction<Reg> {
Aes32Dsi {
rd: Reg,
rs1: Reg,
rs2: Reg,
bs: Rv32AesBs,
},
Aes32Dsmi {
rd: Reg,
rs1: Reg,
rs2: Reg,
bs: Rv32AesBs,
},
}Expand description
RISC-V RV32 Zknd instructions (AES decryption)
Variants
Aes32Dsi
AES final round decryption step: InvSubBytes on one byte of rs2, rotated to the byte lane selected by bs, XOR’d into rs1.
rd = rs1 ^ rol32(INV_SBOX[(rs2 >> (bs*8)) & 0xff] as u32, bs*8)
Aes32Dsmi
AES middle round decryption step: InvSubBytes + partial InvMixColumns on one byte of rs2, rotated to the byte lane selected by bs, XOR’d into rs1.
rd = rs1 ^ rol32(InvMixColByte(INV_SBOX[(rs2 >> (bs*8)) & 0xff]), bs*8)